﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace STC89C5xProgrammer
{
    public partial class ChipInfo : Form
    {
        public int magic { get; set; }
        public double crystalMHz { get; set; }
        public int bslVersion { get; set; }
        public byte optionsByte { get; set; }

        private Form1 parent = null;

        public ChipInfo(Form1 parentForm)
        {
            InitializeComponent();
            parent = parentForm;
            Icon = parent.Icon;
        }

        public void clear()
        {
            Utils.SetControlPropertyValue(chipTypeText, "Text", "");
            Utils.SetControlPropertyValue(MHzText, "Text", "");
            Utils.SetControlPropertyValue(bootLoaderText, "Text", "");
            Utils.SetControlPropertyValue(highSpeedCheck, "Checked", false);
            Utils.SetControlPropertyValue(bslPinCheck, "Checked", false);
            Utils.SetControlPropertyValue(eepromCheck, "Checked", false);
            Utils.SetControlPropertyValue(highGainCheck, "Checked", false);
            Utils.SetControlPropertyValue(aleCheck, "Checked", false);
            Utils.SetControlPropertyValue(xramCheck, "Checked", false);
            Utils.SetControlPropertyValue(watchdogCheck, "Checked", false);
        }

        public void update()
        {
            // Utils.SetControlPropertyValue(this, "Text", optionsByte.ToString("X2"));
            string chipString = "Unknown type id: " + magic.ToString("X4");
            switch (magic)
            {
                case 0xF001:
                    chipString = "STC89C51RC/LE51R";
                    break;
                case 0xF002:
                    chipString = "STC89C52RC/LE52R";
                    break;
                case 0xF004:
                    chipString = "STC89C53RC/LE53R";
                    break;
                case 0xF006:
                    chipString = "STC89C06RC/LE06R";
                    break;
                case 0xF007:
                    chipString = "STC89C07RC/LE07R";
                    break;
                case 0xF00A:
                    chipString = "STC89C10RC/LE10R";
                    break;
                case 0xF00C:
                    chipString = "STC89C12RC/LE12R";
                    break;
                case 0xF050:
                    chipString = "STC89C51";
                    break;
                case 0xF051:
                    chipString = "STC89C52";
                    break;
                case 0xF052:
                    chipString = "STC89C53";
                    break;
                case 0xF053:
                    chipString = "STC89C14";
                    break;
                case 0xF060:
                    chipString = "STC89LE51";
                    break;
                case 0xF061:
                    chipString = "STC89LE52";
                    break;
                case 0xF062:
                    chipString = "STC89LE53";
                    break;
                case 0xF063:
                    chipString = "STC89LE14";
                    break;
                case 0xF101:
                    chipString = "STC89C51RD+/LE51";
                    break;
                case 0xF102:
                    chipString = "STC89C52RD+/LE52";
                    break;
                case 0xF104:
                    chipString = "STC89C54RD+/LE54";
                    break;
                case 0xF105:
                    chipString = "STC89C55RD+/LE55";
                    break;
                case 0xF108:
                    chipString = "STC89C58RD+/LE58";
                    break;
                case 0xF10A:
                    chipString = "STC89C510RD+/LE5";
                    break;
                case 0xF10C:
                    chipString = "STC89C512RD+/LE5";
                    break;
                case 0xF10D:
                    chipString = "STC89C513RD+/LE5";
                    break;
                case 0xF10E:
                    chipString = "STC89C514RD+/LE5";
                    break;
                case 0xF110:
                    chipString = "STC89C516RD+/LE5";
                    break;
                case 0xF1A0:
                    chipString = "STC89C54";
                    break;
                case 0xF1A1:
                    chipString = "STC89C58";
                    break;
                case 0xF1A2:
                    chipString = "STC89C510";
                    break;
                case 0xF1A3:
                    chipString = "STC89C512";
                    break;
                case 0xF1A4:
                    chipString = "STC89C514";
                    break;
                case 0xF1A5:
                    chipString = "STC89C516";
                    break;
                case 0xF1B0:
                    chipString = "STC89LE54";
                    break;
                case 0xF1B1:
                    chipString = "STC89LE58";
                    break;
                case 0xF1B2:
                    chipString = "STC89LE510";
                    break;
                case 0xF1B3:
                    chipString = "STC89LE512";
                    break;
                case 0xF1B4:
                    chipString = "STC89LE514";
                    break;
                case 0xF1B5:
                    chipString = "STC89C516";
                    break;
                case 0xFFFF:
                    chipString = "STC89C516RD/LV551";
                    break;
            }

            string bslString = (bslVersion >> 12).ToString("X1") + "." + ((bslVersion & 0x0F00) >> 8).ToString("X1") + (char)(bslVersion & 0x00FF);
            Utils.SetControlPropertyValue(chipTypeText, "Text", chipString);
            Utils.SetControlPropertyValue(MHzText, "Text", crystalMHz.ToString("F1"));
            Utils.SetControlPropertyValue(bootLoaderText, "Text", bslString);
            Utils.SetControlPropertyValue(highSpeedCheck, "Checked", (optionsByte & 0x01) == 0);
            Utils.SetControlPropertyValue(bslPinCheck, "Checked", (optionsByte & 0x04) == 0);
            Utils.SetControlPropertyValue(eepromCheck, "Checked", (optionsByte & 0x08) == 0);
            Utils.SetControlPropertyValue(highGainCheck, "Checked", (optionsByte & 0x10) != 0);
            Utils.SetControlPropertyValue(aleCheck, "Checked", (optionsByte & 0x20) != 0);
            Utils.SetControlPropertyValue(xramCheck, "Checked", (optionsByte & 0x40) != 0);
            Utils.SetControlPropertyValue(watchdogCheck, "Checked", (optionsByte & 0x80) == 0);
        }

        private void ChipInfo_FormClosing(object sender, FormClosingEventArgs e)
        {
            Hide();
            e.Cancel = true;
        }
    }
}
